Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2684)

Unified Diff: cc/raster/task_graph_work_queue.cc

Issue 1866043006: cc: Remove ScheduleOnOriginThread() and CompleteOnOriginThread(). (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: nits Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: cc/raster/task_graph_work_queue.cc
diff --git a/cc/raster/task_graph_work_queue.cc b/cc/raster/task_graph_work_queue.cc
index 807539db8e49252a01c6b346a625525c7d326d85..291a06f46510d16095a902816e00aaa5bdb23c34 100644
--- a/cc/raster/task_graph_work_queue.cc
+++ b/cc/raster/task_graph_work_queue.cc
@@ -189,8 +189,8 @@ void TaskGraphWorkQueue::ScheduleTasks(NamespaceToken token, TaskGraph* graph) {
it != graph->nodes.end(); ++it) {
TaskGraph::Node& node = *it;
- // Skip if already finished running task.
- if (node.task->state().IsFinished())
+ // Skip if already finished or completed.
+ if (node.task->state().IsFinished() || node.task->state().IsCompleted())
continue;
// Skip if already running.

Powered by Google App Engine
This is Rietveld 408576698